@@ -1,6 +1,6 @@
 __author__ = """Romain Picard"""
 __email__ = 'romain.picard@oakbits.com'
-__version__ = '0.6.0'
+__version__ = '0.7.0'
 
 from enum import Enum
 
@@ -16,13 +16,3 @@ from .mux import (
 import rxsci.data as data
 import rxsci.math as math
 import rxsci.operators as ops
-
-from .assert_ import assert_, assert_1
-from .flat_map import flat_map
-from .on_subscribe import on_subscribe
-from .progress import progress
-from .tee_map import tee_map
-from .train_test_split import train_test_split
-from .with_latest_from import with_latest_from
-
-
