@@ -1,9 +1,11 @@
 from .cache import cache
 from .clip import clip
 from .fill_none import fill_none
-from .lag import lag1, lag
+from .lag import lag
+from .pad import pad_start, pad_end
+from .to_array import to_array
 from .to_deque import to_deque
-from .distinct import distinct
 from .roll import roll
 from .sort import sort
 from .split import split
+from .train_test_split import train_test_split
