@@ -7,17 +7,9 @@ from rx.subject import Subject
 from rxsci.operators.multiplex import demux_mux_observable
 
 
-def roll_mux(window, stride=None):
+def roll_mux(window, stride):
     outer_observer = Subject()
 
-    if window <= 0:
-        raise ValueError()
-
-    if stride is None:
-        stride = window
-    if stride <= 0:
-        raise ValueError()
-
     density = window // stride
     if window % stride:
         density += 1
@@ -32,8 +24,8 @@ def roll_mux(window, stride=None):
                     n = state_n[i.key[0]]
 
                     if (n % stride) == 0:
-                        index = (n // stride) % density
-                        index = i.key[0] * density + index
+                        offset = (n // stride) % density
+                        index = i.key[0] * density + offset
                         state_w[index] = n
                         observer.on_next(rs.OnCreateMux((index, i.key)))
 
@@ -46,7 +38,6 @@ def roll_mux(window, stride=None):
                                 state_w[index] = -1
                                 observer.on_next(rs.OnCompletedMux((index, i.key)))
 
-
                     state_n[i.key[0]] += 1
 
                 elif isinstance(i, rs.OnCreateMux):
@@ -62,14 +53,14 @@ def roll_mux(window, stride=None):
                 elif isinstance(i, rs.OnCompletedMux):
                     kindex = i.key[0]
                     state_n[kindex] = 0
-                    for offset in range(density):                        
+                    for offset in range(density):
                         state_w[kindex+offset] = -1
                     #observer.on_next(rs.OnCompletedMux((1, i.key)))
                     outer_observer.on_next(i)
                 elif isinstance(i, rs.OnErrorMux):
                     kindex = i.key[0]
                     state_n[kindex] = 0
-                    for offset in range(density):                        
+                    for offset in range(density):
                         state_w[kindex+offset] = -1
                     #observer.on_next(rs.OnErrordMux((1, i.key), i.error))
                     outer_observer.on_next(i)
@@ -99,9 +90,9 @@ def roll_mux(window, stride=None):
                     if count == 0:
                         observer.on_next(rs.OnCreateMux((1, i.key)))
 
-                    count += 1                    
+                    count += 1
                     observer.on_next(rs.OnNextMux((1, i.key), i.item))
-        
+
                     if count == window:
                         state[i.key] = 0
                         observer.on_next(rs.OnCompletedMux((1, i.key)))
@@ -141,7 +132,7 @@ def roll(window, stride, pipeline):
         :alt: roll
 
         -1-2-3-4-5-6-------|
-        [      roll(3)     ]
+        [     roll(3,3)    ]
         -+-----+-----------|
                +4-5-6|
          +1-2-3|
@@ -154,13 +145,23 @@ def roll(window, stride, pipeline):
         window: Length of each window.
         stride: Number of elements to step between creation of
             consecutive windows.
+        pipeline: The Rx pipe to execute on each window.
+
+    Source:
+        A MuxObservable.
 
     Returns:
         An observable sequence of windows.
 
     Raises:
-        ValueError if window or step is negative
+        ValueError if window or stride is negative
     """
+    if window <= 0:
+        raise ValueError()
+
+    if stride <= 0:
+        raise ValueError()
+
     _roll, outer_obs = roll_mux(window, stride)
 
     return rx.pipe(
