@@ -57,3 +57,33 @@ def test_clip_invalid_bound():
         rx.from_(source).pipe(
             rs.data.clip(lower_bound=8, higher_bound=3)
         ).subscribe()
+
+
+def test_clip_mux():
+    source = [
+        rs.OnCreateMux((1 ,None)),
+        rs.OnNextMux((1, None), 1),
+        rs.OnNextMux((1, None), 2),
+        rs.OnNextMux((1, None), 3),
+        rs.OnNextMux((1, None), 4),
+        rs.OnNextMux((1, None), 5),
+        rs.OnNextMux((1, None), 6),
+        rs.OnCompletedMux((1, None)),
+    ]
+    actual_result = []
+
+    rx.from_(source).pipe(
+        rs.cast_as_mux_observable(),
+        rs.data.clip(lower_bound=2, higher_bound=5)
+    ).subscribe(on_next=actual_result.append)
+
+    assert actual_result == [
+        rs.OnCreateMux((1 ,None)),
+        rs.OnNextMux((1, None), 2),
+        rs.OnNextMux((1, None), 2),
+        rs.OnNextMux((1, None), 3),
+        rs.OnNextMux((1, None), 4),
+        rs.OnNextMux((1, None), 5),
+        rs.OnNextMux((1, None), 5),
+        rs.OnCompletedMux((1, None)),
+    ]
